﻿using System;
using System.Linq;
using System.Windows;
using StockSharp.Algo.Candles;
using StockSharp.BusinessEntities;
using StockSharp.Xaml.Charting;
using StockSharp.Quik;
using Ecng.Xaml;
using StockSharp.Messages;

namespace ShowChart
{
    /// <summary>
    /// Логика взаимодействия для MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private readonly QuikTrader _trader;
        private Security _security;
        public static CandleManager CandleManager { get; private set; }
        public static CandleSeries Series { get; private set; }
        public CandleSeries CandleSeries { get; private set; }
        public ChartCandleElement ChartCandleElement { get; private set; }
        public bool IsRealtiem { get; private set; }
        public TimeSpan TimeFrame => TimeSpan.FromMinutes(1);
        public MainWindow()
        {
            InitializeComponent();
            _trader = new QuikTrader();
            _trader.NewSecurity += security =>
            {
                if (security.Id == "SBER@QJSIM" && _security == null)
                {
                    _security = security;
                    Start();
                }
            };
            _trader.Connect();

        }

        private void Start()
        {
            if (CandleManager == null) CandleManager = new CandleManager(_trader);
            if (CandleSeries == null) CandleSeries = new CandleSeries(typeof(TimeFrameCandle), _security, TimeFrame);

            this.GuiAsync(() =>
            {
                InitCart();
                StartButton.IsEnabled = StopButton.IsEnabled = true;
            });
        }

        public void InitCart()
        {
            Chart.ClearAreas();

            var area = new ChartArea();
            var yAxis = area.YAxises.First();
            yAxis.AutoRange = true;
            Chart.IsAutoScroll = true;
            Chart.ShowOverview = true;
            Chart.AddArea(area);
            ChartCandleElement = new ChartCandleElement();
            Chart.AddElement(area,ChartCandleElement);
        }

        private void DisplayNewMarketData(CandleSeries candleSeries, Candle candle)
        {
            IsRealtiem = candle.OpenTime + TimeFrame >= DateTimeOffset.Now || IsRealtiem;

            var chartDrawData = new ChartDrawData();
            var group = chartDrawData.Group(candle.OpenTime);
            group.Add(ChartCandleElement, candle);
            if (IsRealtiem || candle.State == CandleStates.Finished)
                Chart.Draw(chartDrawData);
        }

        private void StartButton_Click(object sender, RoutedEventArgs e)
        {
            CandleManager.Processing += DisplayNewMarketData;
            CandleManager.Start(CandleSeries);
        }

        private void StopButton_Click(object sender, RoutedEventArgs e)
        {
            CandleManager.Processing -= DisplayNewMarketData;
            CandleManager.Stop(CandleSeries);
            IsRealtiem = false;
            InitCart();
        }
    }
}
